# Exomiser Runner for PhEval

This is the Exomiser plugin for PhEval. Highly experimental. Do not use.

## Developers

Warning, the `pheval` library is currently included as a file reference in the toml file.

```
pheval = { path = "/Users/matentzn/ws/pheval" }
```

This will change when pheval is published on pypi.

